@@ -96,7 +96,7 @@ impl BuiltinSqlTypes {
 
     pub fn deserialize(
         target_type: DeserializeTypes,
-        mut buffer: impl Buf,
+        buffer: &mut impl Buf,
     ) -> Result<Self, SqlTypeError> {
         match target_type {
             DeserializeTypes::Bool => {
@@ -115,6 +115,7 @@ impl BuiltinSqlTypes {
                 if buffer.remaining() < mem::size_of::<u32>() {
                     return Err(SqlTypeError::LengthTooShort(buffer.remaining()));
                 }
+
                 let dest = buffer.get_u32_le();
                 let value = BuiltinSqlTypes::Integer(dest);
 
@@ -169,12 +170,12 @@ impl BuiltinSqlTypes {
         }
     }
 
-    pub fn parse(target_type: DeserializeTypes, buffer: String) -> Result<Self, SqlTypeError> {
+    pub fn parse(target_type: DeserializeTypes, buffer: &str) -> Result<Self, SqlTypeError> {
         match target_type {
             DeserializeTypes::Bool => Ok(BuiltinSqlTypes::Bool(buffer.parse::<bool>()?)),
             DeserializeTypes::Integer => Ok(BuiltinSqlTypes::Integer(buffer.parse::<u32>()?)),
             DeserializeTypes::Uuid => Ok(BuiltinSqlTypes::Uuid(uuid::Uuid::parse_str(&buffer)?)),
-            DeserializeTypes::Text => Ok(BuiltinSqlTypes::Text(buffer)),
+            DeserializeTypes::Text => Ok(BuiltinSqlTypes::Text(buffer.to_string())),
         }
     }
 }
@@ -253,12 +254,16 @@ pub enum SqlTypeError {
 
 #[cfg(test)]
 mod tests {
+
+    use hex_literal::hex;
+    use uuid::Uuid;
+
     use super::*;
 
     fn roundtrip(input: String) -> String {
         let stype = BuiltinSqlTypes::Text(input);
-        let serialized = stype.serialize();
-        let result = BuiltinSqlTypes::deserialize(DeserializeTypes::Text, serialized).unwrap();
+        let mut serialized = stype.serialize();
+        let result = BuiltinSqlTypes::deserialize(DeserializeTypes::Text, &mut serialized).unwrap();
         match result {
             BuiltinSqlTypes::Text(t) => t,
             _ => {
@@ -275,6 +280,27 @@ mod tests {
         assert_eq!(output, test);
     }
 
+    #[test]
+    fn test_builtin_display() {
+        let text = BuiltinSqlTypes::Bool(true);
+        assert_eq!(text.to_string(), "true");
+
+        let text = BuiltinSqlTypes::Integer(5);
+        assert_eq!(text.to_string(), "5");
+
+        let text = BuiltinSqlTypes::Text("FOOBAR".to_string());
+        assert_eq!(text.to_string(), "FOOBAR");
+
+        let text =
+            BuiltinSqlTypes::Uuid(Uuid::from_bytes(hex!("EE919E33D9054F4889537EBB6CC911EB")));
+        assert_eq!(text.to_string(), "ee919e33-d905-4f48-8953-7ebb6cc911eb");
+
+        assert_eq!(DeserializeTypes::Bool.to_string(), "Bool");
+        assert_eq!(DeserializeTypes::Integer.to_string(), "Integer");
+        assert_eq!(DeserializeTypes::Text.to_string(), "Text");
+        assert_eq!(DeserializeTypes::Uuid.to_string(), "Uuid");
+    }
+
     #[test]
     fn test_long_roundtrip() {
         let test = "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec vel porta enim. Sed interdum egestas velit et porttitor. Vestibulum sollicitudin mi enim, in fringilla lectus tincidunt quis. Morbi eget.";
@@ -283,6 +309,30 @@ mod tests {
         assert_eq!(output, test);
     }
 
+    #[test]
+    fn test_integer_roundtrip() -> Result<(), Box<dyn std::error::Error>> {
+        let test = "5";
+        let parse_str = BuiltinSqlTypes::parse(DeserializeTypes::Integer, test)?;
+        match parse_str {
+            BuiltinSqlTypes::Integer(i) => {
+                assert_eq!(i, 5);
+                i
+            }
+            _ => panic!("Wrong type"),
+        };
+
+        let mut parse_serial = parse_str.serialize();
+        let reparse = BuiltinSqlTypes::deserialize(DeserializeTypes::Integer, &mut parse_serial)?;
+        match reparse {
+            BuiltinSqlTypes::Integer(i) => {
+                assert_eq!(i, 5)
+            }
+            _ => panic!("Wrong type"),
+        };
+
+        Ok(())
+    }
+
     #[test]
     //Used to map if we have the types linked up right
     pub fn test_type_matches() {
