@@ -27,16 +27,11 @@ pub use sql_parser::SqlParserError;
 pub mod transactions;
 use transactions::{TransactionId, TransactionManager};
 
-use std::ops::Deref;
-use std::sync::Arc;
-use thiserror::Error;
-use tokio::sync::RwLock;
-use tokio_stream::StreamExt;
-
-use crate::engine::objects::TargetEntry;
-
+use self::io::ConstraintManager;
 use self::objects::QueryResult;
-use self::objects::SqlTuple;
+use std::ops::Deref;
+use thiserror::Error;
+use tokio_stream::StreamExt;
 
 #[derive(Clone, Debug)]
 pub struct Engine {
@@ -45,11 +40,12 @@ pub struct Engine {
 }
 
 impl Engine {
-    pub fn new(io_manager: Arc<RwLock<IOManager>>, tran_manager: TransactionManager) -> Engine {
+    pub fn new(io_manager: IOManager, tran_manager: TransactionManager) -> Engine {
         let vis_row_man = VisibleRowManager::new(RowManager::new(io_manager), tran_manager);
+        let con_man = ConstraintManager::new(vis_row_man.clone());
         Engine {
-            analyzer: Analyzer::new(vis_row_man.clone()),
-            executor: Executor::new(vis_row_man),
+            analyzer: Analyzer::new(vis_row_man),
+            executor: Executor::new(con_man),
         }
     }
 
@@ -87,13 +83,7 @@ impl Engine {
             result.push(value?);
         }
 
-        let output_columns = query_tree
-            .targets
-            .into_iter()
-            .map(|t| match t {
-                TargetEntry::Parameter(p) => p.name,
-            })
-            .collect();
+        let output_columns = query_tree.targets.iter().map(|t| t.0.clone()).collect();
 
         return Ok(QueryResult {
             columns: output_columns,
@@ -130,7 +120,6 @@ mod tests {
     use super::io::IOManager;
     use super::transactions::TransactionManager;
     use super::*;
-    use tokio::sync::RwLock;
 
     macro_rules! aw {
         ($e:expr) => {
@@ -145,18 +134,14 @@ mod tests {
         let select_test = "select bar from foo".to_string();
 
         let mut transaction_manager = TransactionManager::new();
-        let mut engine = Engine::new(
-            Arc::new(RwLock::new(IOManager::new())),
-            transaction_manager.clone(),
-        );
+        let mut engine = Engine::new(IOManager::new(), transaction_manager.clone());
 
         let tran = aw!(transaction_manager.start_trans())?;
         aw!(engine.process_query(tran, create_test))?;
         aw!(transaction_manager.commit_trans(tran))?;
 
-        //Postgres equivalent
-        //assert_eq!(aw!(engine.process_query(tran, insert_test)).unwrap(), ());
-        //assert!(aw!(engine.process_query(tran, select_test)).is_ok());
+        aw!(engine.process_query(tran, insert_test))?;
+        aw!(engine.process_query(tran, select_test))?;
 
         Ok(())
     }
