@@ -1,29 +1,24 @@
-//! The current goal of the row manager is to provide an interative interface over a table's pages.
-//!
-//! It will provide a raw scan over a table, insert and update. Update has been deferred until I figure out transactions.
-//!
-//! NO LOCKING or transaction control yet. I did implement it at the IO layer but its probably wrong.
-
-use crate::engine::objects::SqlTuple;
-
 use super::super::objects::Table;
 use super::super::transactions::TransactionId;
 use super::page_formats::{PageData, PageDataError, UInt12};
 use super::row_formats::{ItemPointer, RowData, RowDataError};
-use super::{IOManager, IOManagerError};
+use super::{EncodedSize, IOManager, IOManagerError};
+use crate::engine::objects::SqlTuple;
 use async_stream::try_stream;
 use futures::stream::Stream;
 use std::sync::Arc;
 use thiserror::Error;
-use tokio::sync::RwLock;
 
+/// The row manager is a mapper between rows and pages on disk.
+///
+/// It operates at the lowest level, no visibility checks are done.
 #[derive(Clone, Debug)]
 pub struct RowManager {
-    io_manager: Arc<RwLock<IOManager>>,
+    io_manager: IOManager,
 }
 
 impl RowManager {
-    pub fn new(io_manager: Arc<RwLock<IOManager>>) -> RowManager {
+    pub fn new(io_manager: IOManager) -> RowManager {
         RowManager { io_manager }
     }
 
@@ -31,10 +26,10 @@ impl RowManager {
         self,
         current_tran_id: TransactionId,
         table: Arc<Table>,
-        user_data: Arc<SqlTuple>,
+        user_data: SqlTuple,
     ) -> Result<ItemPointer, RowManagerError> {
-        let io_mut = self.io_manager.write().await;
-        RowManager::insert_row_internal(&io_mut, current_tran_id, table, user_data).await
+        RowManager::insert_row_internal(self.io_manager.clone(), current_tran_id, table, user_data)
+            .await
     }
 
     //Note this is a logical delete
@@ -58,9 +53,8 @@ impl RowManager {
 
         page.update(row, row_pointer.count)?;
 
-        let io_mut = self.io_manager.write().await;
-        io_mut
-            .update_page(table, page.serialize(), row_pointer.page)
+        self.io_manager
+            .update_page(&table.id, page.serialize(), row_pointer.page)
             .await?;
         Ok(())
     }
@@ -71,8 +65,8 @@ impl RowManager {
         current_tran_id: TransactionId,
         table: Arc<Table>,
         row_pointer: ItemPointer,
-        new_user_data: Arc<SqlTuple>,
-    ) -> Result<(), RowManagerError> {
+        new_user_data: SqlTuple,
+    ) -> Result<ItemPointer, RowManagerError> {
         //First get the current row so we have it for the update/delete
         let (mut old_page, mut old_row) = self.get(table.clone(), row_pointer).await?;
 
@@ -83,25 +77,15 @@ impl RowManager {
             ));
         }
 
-        //Serialize with a dummy pointer so we can evaluate space needed for the new row
-        let new_row = RowData::new(
-            table.clone(),
-            current_tran_id,
-            None,
-            ItemPointer::new(0, UInt12::new(0).unwrap()),
-            new_user_data.clone(),
-        )?;
-        let new_row_len = new_row.serialize().len();
-
-        let io_mut = self.io_manager.write().await;
+        let new_row_len = RowData::encoded_size(&new_user_data);
 
         //Prefer using the old page if possible
         let new_row_pointer;
         if old_page.can_fit(new_row_len) {
-            new_row_pointer = old_page.insert(new_row)?;
+            new_row_pointer = old_page.insert(current_tran_id, &table, new_user_data)?;
         } else {
             new_row_pointer = RowManager::insert_row_internal(
-                &io_mut,
+                self.io_manager.clone(),
                 current_tran_id,
                 table.clone(),
                 new_user_data,
@@ -111,14 +95,13 @@ impl RowManager {
 
         old_row.max = Some(current_tran_id);
         old_row.item_pointer = new_row_pointer;
-
         old_page.update(old_row, row_pointer.count)?;
 
-        io_mut
-            .update_page(table, old_page.serialize(), row_pointer.page)
+        self.io_manager
+            .update_page(&table.id, old_page.serialize(), row_pointer.page)
             .await?;
 
-        return Ok(());
+        return Ok(new_row_pointer);
     }
 
     pub async fn get(
@@ -126,12 +109,12 @@ impl RowManager {
         table: Arc<Table>,
         row_pointer: ItemPointer,
     ) -> Result<(PageData, RowData), RowManagerError> {
-        let io = self.io_manager.read().await;
-        let page_bytes = io
-            .get_page(table.clone(), row_pointer.page)
+        let page_bytes = self
+            .io_manager
+            .get_page(&table.id, row_pointer.page)
             .await
             .ok_or_else(|| RowManagerError::NonExistentPage(row_pointer.page))?;
-        let page = PageData::parse(table.clone(), row_pointer.page, page_bytes)?;
+        let page = PageData::parse(table, row_pointer.page, page_bytes)?;
 
         let row = page
             .get_row(row_pointer.count)
@@ -147,9 +130,8 @@ impl RowManager {
         table: Arc<Table>,
     ) -> impl Stream<Item = Result<RowData, RowManagerError>> {
         try_stream! {
-            let io_man = self.io_manager.read().await;
             let mut page_num = 0;
-            for await page_bytes in io_man.get_stream(table.clone()) {
+            for await page_bytes in self.io_manager.get_stream(table.id) {
                 let page = PageData::parse(table.clone(), page_num, page_bytes)?;
                 for await row in page.get_stream() {
                     yield row;
@@ -160,32 +142,22 @@ impl RowManager {
     }
 
     async fn insert_row_internal(
-        io_manager: &IOManager,
+        io_manager: IOManager,
         current_tran_id: TransactionId,
         table: Arc<Table>,
-        user_data: Arc<SqlTuple>,
+        user_data: SqlTuple,
     ) -> Result<ItemPointer, RowManagerError> {
-        //Serialize with a dummy pointer so we can evaluate space needed
-        let row = RowData::new(
-            table.clone(),
-            current_tran_id,
-            None,
-            ItemPointer::new(0, UInt12::new(0).unwrap()),
-            user_data,
-        )?;
-        let row_len = row.serialize().len();
-
         let mut page_num = 0;
         loop {
-            let page_bytes = io_manager.get_page(table.clone(), page_num).await;
+            let page_bytes = io_manager.get_page(&table.id, page_num).await;
             match page_bytes {
                 Some(p) => {
                     let mut page = PageData::parse(table.clone(), page_num, p)?;
-                    if page.can_fit(row_len) {
-                        let new_row_pointer = page.insert(row)?;
+                    if page.can_fit(RowData::encoded_size(&user_data)) {
+                        let new_row_pointer = page.insert(current_tran_id, &table, user_data)?;
                         let new_page_bytes = page.serialize();
                         io_manager
-                            .update_page(table, new_page_bytes, page_num)
+                            .update_page(&table.id, new_page_bytes, page_num)
                             .await?;
                         return Ok(new_row_pointer);
                     } else {
@@ -195,8 +167,8 @@ impl RowManager {
                 }
                 None => {
                     let mut new_page = PageData::new(page_num);
-                    let new_row_pointer = new_page.insert(row)?; //TODO Will NOT handle overly large rows
-                    io_manager.add_page(table, new_page.serialize()).await;
+                    let new_row_pointer = new_page.insert(current_tran_id, &table, user_data)?; //TODO Will NOT handle overly large rows
+                    io_manager.add_page(&table.id, new_page.serialize()).await?;
                     return Ok(new_row_pointer);
                 }
             }
@@ -224,18 +196,15 @@ pub enum RowManagerError {
 
 #[cfg(test)]
 mod tests {
-    use crate::constants::BuiltinSqlTypes;
-    use crate::constants::Nullable;
-
-    // Note this useful idiom: importing names from outer (for mod tests) scope.
-    use super::super::super::super::constants::DeserializeTypes;
     use super::super::super::objects::Attribute;
     use super::super::super::objects::Table;
     use super::*;
+    use crate::constants::Nullable;
+    use crate::engine::objects::types::BaseSqlTypes;
+    use crate::engine::objects::types::BaseSqlTypesMapper;
     use futures::pin_mut;
     use futures::stream::StreamExt;
 
-    //Async testing help can be found here: https://blog.x5ff.xyz/blog/async-tests-tokio-rust/
     macro_rules! aw {
         ($e:expr) => {
             tokio_test::block_on($e)
@@ -244,42 +213,43 @@ mod tests {
 
     fn get_table() -> Arc<Table> {
         Arc::new(Table::new(
+            uuid::Uuid::new_v4(),
             "test_table".to_string(),
             vec![
                 Attribute::new(
-                    uuid::Uuid::new_v4(),
                     "header".to_string(),
-                    DeserializeTypes::Text,
+                    BaseSqlTypesMapper::Text,
                     Nullable::NotNull,
+                    None,
                 ),
                 Attribute::new(
-                    uuid::Uuid::new_v4(),
                     "id".to_string(),
-                    DeserializeTypes::Uuid,
+                    BaseSqlTypesMapper::Uuid,
                     Nullable::Null,
+                    None,
                 ),
                 Attribute::new(
-                    uuid::Uuid::new_v4(),
                     "header3".to_string(),
-                    DeserializeTypes::Text,
+                    BaseSqlTypesMapper::Text,
                     Nullable::NotNull,
+                    None,
                 ),
             ],
         ))
     }
 
-    fn get_row(input: String) -> Arc<SqlTuple> {
-        Arc::new(SqlTuple(vec![
-                Some(BuiltinSqlTypes::Text(input)),
+    fn get_row(input: String) -> SqlTuple {
+        SqlTuple(vec![
+                Some(BaseSqlTypes::Text(input)),
                 None,
-                Some(BuiltinSqlTypes::Text("blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah".to_string())),
-            ]))
+                Some(BaseSqlTypes::Text("blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah blah".to_string())),
+            ])
     }
 
     #[test]
-    fn test_row_manager_mass_insert() {
+    fn test_row_manager_mass_insert() -> Result<(), Box<dyn std::error::Error>> {
         let table = get_table();
-        let pm = Arc::new(RwLock::new(IOManager::new()));
+        let pm = IOManager::new();
         let rm = RowManager::new(pm);
 
         let tran_id = TransactionId::new(1);
@@ -305,12 +275,14 @@ mod tests {
         for row in result_rows {
             assert_eq!(row.user_data, sample_row);
         }
+
+        Ok(())
     }
 
     #[test]
-    fn test_row_manager_crud() {
+    fn test_row_manager_crud() -> Result<(), Box<dyn std::error::Error>> {
         let table = get_table();
-        let pm = Arc::new(RwLock::new(IOManager::new()));
+        let pm = IOManager::new();
         let rm = RowManager::new(pm);
 
         let tran_id = TransactionId::new(1);
@@ -318,16 +290,32 @@ mod tests {
         let insert_pointer =
             aw!(rm
                 .clone()
-                .insert_row(tran_id, table.clone(), get_row("test".to_string())));
-        assert!(insert_pointer.is_ok());
+                .insert_row(tran_id, table.clone(), get_row("test".to_string())))?;
 
-        let insert_pointer = insert_pointer.unwrap();
+        let tran_id_2 = TransactionId::new(3);
 
-        let tran_id_2 = TransactionId::new(2);
+        let update_pointer = aw!(rm.clone().update_row(
+            tran_id_2,
+            table.clone(),
+            insert_pointer,
+            get_row("test2".to_string())
+        ))?;
 
-        let delete_res = aw!(rm
+        //Now let's make sure the update took
+        pin_mut!(rm);
+        let result_rows: Vec<RowData> = aw!(rm
             .clone()
-            .delete_row(tran_id_2, table.clone(), insert_pointer));
-        assert!(delete_res.is_ok());
+            .get_stream(table.clone())
+            .map(Result::unwrap)
+            .collect());
+        assert_eq!(result_rows.len(), 2);
+
+        let tran_id_3 = TransactionId::new(3);
+
+        aw!(rm
+            .clone()
+            .delete_row(tran_id_3, table.clone(), update_pointer))?;
+
+        Ok(())
     }
 }
