@@ -10,9 +10,7 @@ use feophantlib::processor::ClientProcessor;
 use futures::sink::SinkExt;
 use futures::stream::StreamExt;
 use simplelog::{ColorChoice, CombinedLogger, Config, LevelFilter, TermLogger, TerminalMode};
-use std::sync::Arc;
 use tokio::net::TcpListener;
-use tokio::sync::RwLock;
 use tokio_util::codec::Framed;
 
 #[tokio::main]
@@ -28,7 +26,7 @@ async fn main() {
     info!("Welcome to FeOphant!");
 
     //Start the services first
-    let io_manager = Arc::new(RwLock::new(IOManager::new()));
+    let io_manager = IOManager::new();
     let transaction_manager = TransactionManager::new();
     let engine = Engine::new(io_manager, transaction_manager.clone());
 
