@@ -1,6 +1,4 @@
 use feophantlib::engine::{io::IOManager, transactions::TransactionManager, Engine};
-use std::sync::Arc;
-use tokio::sync::RwLock;
 
 #[macro_export]
 macro_rules! aw {
@@ -11,9 +9,6 @@ macro_rules! aw {
 
 pub fn _create_engine() -> (TransactionManager, Engine) {
     let transaction_manager = TransactionManager::new();
-    let engine = Engine::new(
-        Arc::new(RwLock::new(IOManager::new())),
-        transaction_manager.clone(),
-    );
+    let engine = Engine::new(IOManager::new(), transaction_manager.clone());
     (transaction_manager, engine)
 }
